#!/usr/bin/python
from setuptools import setup, find_packages  # Always prefer setuptools over distutils
from codecs import open  # To use a consistent encoding
from os import path
import sys

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

install_requires = []
pyversion = sys.version_info[:2]
if pyversion < (2, 7) or (3, 0) <= pyversion <= (3, 1):
    install_requires.append('argparse')

setup(
    name="rpm-uploader",

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # http://packaging.python.org/en/latest/tutorial.html#version
    version='0.2.1',

    description="A tool to upload rpms into repositories.",
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/Guavus/rpm-uploader',

    # Author details
    author='Damien Dube',
    author_email='pypa-dev@googlegroups.com',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],

    # What does your project relate to?
    keywords='rpm',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=["contrib", "docs", "tests*"]),

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        'console_scripts': [
            'rpm-uploader=rpm_uploader:main',
        ],
    },
    install_requires=[
        'setuptools', 'bottle'
        ] + install_requires,
)



#!/usr/bin/python

from __future__ import (absolute_import, division, print_function, unicode_literals)
import sys
import os
import json
import subprocess
import argparse
import socket
from bottle import route, request, response, run


configs={}

@route('/upload', method='POST')
def upload():
    global configs
    input_data_files = request.files.getall('data')
    project = request.query.get('dir', '')

    if len(input_data_files) <= 0:
        if configs['verbose']:
            print('No file specified to upload')
        response.status = 400
        return dict(message='No file specified to upload')

    output_dir = os.path.join(configs['output_dir'], *project.split('/'))
    if not os.path.exists(output_dir):
        os.makedirs(output_dir)

    for data in input_data_files:
        file_path = os.path.join(output_dir, data.filename)
        if os.path.exists(file_path):
            if configs['verbose']:
                print('File already exists.')
            response.status = 400
            return dict(message='File ' + file_path + ' already exists. Will not overwrite')

        # Print
        if configs['verbose']:
            print("Uploading file(s) %s to folder %s." % (data.filename, output_dir))

        # Save file
        data.save(file_path)

    # Update repo
    subprocess.call(configs['createrepo'].split(" ") + [output_dir])

    return dict(result="Success", message="Ok")
    
def main():
    global configs
    parser = argparse.ArgumentParser()
    parser.add_argument('--output-dir')
    parser.add_argument('--port', default='1234', type=int)
    parser.add_argument('--createrepo', default='/usr/bin/createrepo -p --update')
    parser.add_argument('--verbose', dest='verbose', action='store_true')
    parser.add_argument('--silent', dest='verbose', action='store_false')

    parser.set_defaults(verbose=False)
    configs = vars(parser.parse_args(sys.argv[1:]))

    #Run server
    print("Starting on port %s. Will save in %s and run %s in repo." % (configs['port'], configs['output_dir'], configs['createrepo']))
    run(host=socket.gethostname(), port=configs['port'])

if __name__ == '__main__':
    main()
